@@ -5,9 +5,9 @@
 
 hclust_greedy <- function(dist) {
     if (!inherits(dist, "dist"))
-    stop(paste(sQuote("dist"),"not of class dist"))
-    if (!is.real(dist))
-    mode(dist) <- "real"
+        stop("Argument 'dist' is not of class 'dist'.")
+    if (!is.double(dist))
+    mode(dist) <- "double"
     obj <- .Call("order_greedy", dist)
     names(obj) <- c("merge", "order", "height");
     class(obj) <- "hclust"
